# xbasin
Python package to compute diagnostics of idealized basin global circulation models. NEMO oriented for now. Deals with terrain-following coordinates.

2020-11-02: The vertical transformation function should not be used anymore, see the [xgcm](https://github.com/xgcm/xgcm) package that is the new reference.
